These are the fundamental computing algorithms that cdfPen invokes to estimate penalized linear models by varying lambda.
cdfPen.fit(b,
b.tld,
g,
b.rho,
H.rho,
lmb.rho,
nu,
algorithm,
nstep = 1E+5,
eps = 1E-5,
eps.lla = 1E-6,
nstep.lla = 1E+5)
Estimated beta-vector.
Estimated sparse beta-vector.
Final values of pseudo-variable.
Number of iterations.
Convergence check status (0 if converged).
Starting values of beta-vector.
Starting values of sparse beta-vector.
Starting values of pseudo-variable.
Ridge solution.
Second part of ridge solution.
Lambda-rho ratio.
Shape parameter of the penalty. It affects the degree of the non-convexity of the penalty.
Approximation to be used to obtain the sparse solution.
Maximum number of iterations of the global algorithm.
Convergence threshold of the global algorithm.
Convergence threshold of the LLA-algorithm (if used).
Maximum number of iterations of the LLA-algorithm (if used).
Daniele Cuntrera, Luigi Augugliaro, Vito Muggeo
Aggiungere Arxiv